==> eiffelstudio-18.11.10.2592.tar: F_code/C2/gb81.c <==
/*
 * Code for class GB_NESTING_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb81.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_NESTING_CHECKER}.components */
EIF_REFERENCE F92_2193 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {GB_NESTING_CHECKER}.make_with_components */
void F92_2194 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make_with_components", 91, Current, 0, 1, 2236);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	{
		/* INLINED CODE (default_create) */
		/* END INLINED CODE */
	}
	;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_NESTING_CHECKER}.check_nesting */
void F92_2195 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("check_nesting", 91, Current, 1, 0, 2237);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	loc1 = F2215_25298(RTCW(loc1));
	RTHOOK(2);
	F1145_10797(RTCW(loc1));
	for (;;) {
		RTHOOK(3);
		tb1 = F903_9141(RTCW(loc1));
		if (tb1) break;
		RTHOOK(4);
		tr1 = F1145_10771(RTCW(loc1));
		F92_2196(Current, tr1);
		RTHOOK(5);
		F1145_10799(RTCW(loc1));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {GB_NESTING_CHECKER}.check_object */
void F92_2196 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCFDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc3);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTEAA("check_object", 91, Current, 3, 1, 2238);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1144,2482,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 1144, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1145_10766(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F2483_30334(RTCW(arg1), loc1);
	RTHOOK(3);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7675[Dtype(loc1)-789])(RTCW(loc1), arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
	F1139_10674(RTCW(tr1));
	for (;;) {
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		tb1 = F1139_10670(RTCW(tr1));
		if (tb1) break;
		RTHOOK(6);
		loc3 = *(EIF_REFERENCE *)(Current);
		loc3 = *(EIF_REFERENCE *)(RTCW(loc3) + _REFACS_7_);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		ti4_1 = F1139_10646(RTCW(tr1));
		loc3 = F2504_30538(RTCW(loc3), ti4_1);
		RTHOOK(7);
		{
			static EIF_TYPE_INDEX typarr0[] = {1144,2482,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNS(typres0.id, 1144, _OBJSIZ_1_1_0_1_0_0_0_0_);
		}
		F1145_10766(RTCW(tr1), ((EIF_INTEGER_32) 20L));
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(8);
		F2483_30334(RTCW(loc3), loc2);
		RTHOOK(9);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7675[Dtype(loc2)-789])(RTCW(loc2), loc3);
		
		RTHOOK(11);
		F1145_10797(RTCW(loc1));
		RTHOOK(12);
		F1145_10797(RTCW(loc2));
		for (;;) {
			RTHOOK(13);
			tb2 = F903_9141(RTCW(loc1));
			if (tb2) break;
			
			RTHOOK(15);
			F1145_10799(RTCW(loc2));
			RTHOOK(16);
			F1145_10799(RTCW(loc1));
		}
		RTHOOK(17);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		F1139_10675(RTCW(tr1));
	}
	RTHOOK(18);
	RTLE;
	RTEE;
}

void EIF_Minit81 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/gb81.c <==
/*
 * Code for class GB_NESTING_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb81.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_NESTING_CHECKER}.make_with_components */
void F92_2196 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make_with_components", 91, Current, 0, 1, 2238);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	{
		/* INLINED CODE (ANY.default_create) */
		/* END INLINED CODE */
	}
	;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_NESTING_CHECKER}.check_nesting */
void F92_2197 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("check_nesting", 91, Current, 1, 0, 2239);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	loc1 = F2222_25346(RTCW(loc1));
	RTHOOK(2);
	F1147_10822(RTCW(loc1));
	for (;;) {
		RTHOOK(3);
		tb1 = F905_9161(RTCW(loc1));
		if (tb1) break;
		RTHOOK(4);
		tr1 = F1147_10796(RTCW(loc1));
		F92_2198(Current, tr1);
		RTHOOK(5);
		F1147_10824(RTCW(loc1));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {GB_NESTING_CHECKER}.check_object */
void F92_2198 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCFDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLR(4,loc3);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTEAA("check_object", 91, Current, 3, 1, 2240);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1146,2489,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		loc1 = RTLNS(typres0.id, 1146, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1147_10791(RTCW(loc1), ((EIF_INTEGER_32) 20L));
	RTHOOK(2);
	F2490_30382(RTCW(arg1), loc1);
	RTHOOK(3);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7692[Dtype(RTCW(loc1))-844])(loc1, arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
	F1140_10699(RTCW(tr1));
	for (;;) {
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		tb1 = F1140_10695(RTCW(tr1));
		if (tb1) break;
		RTHOOK(6);
		loc3 = *(EIF_REFERENCE *)(Current);
		loc3 = *(EIF_REFERENCE *)(RTCW(loc3) + _REFACS_7_);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		ti4_1 = F1140_10671(RTCW(tr1));
		loc3 = F2511_30586(RTCW(loc3), ti4_1);
		RTHOOK(7);
		{
			static EIF_TYPE_INDEX typarr0[] = {1146,2489,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTLNS(typres0.id, 1146, _OBJSIZ_1_1_0_1_0_0_0_0_);
		}
		F1147_10791(RTCW(loc2), ((EIF_INTEGER_32) 20L));
		RTHOOK(8);
		F2490_30382(RTCW(loc3), loc2);
		RTHOOK(9);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7692[Dtype(RTCW(loc2))-844])(loc2, loc3);
		
		RTHOOK(11);
		F1147_10822(RTCW(loc1));
		RTHOOK(12);
		F1147_10822(RTCW(loc2));
		for (;;) {
			RTHOOK(13);
			tb2 = F905_9161(RTCW(loc1));
			if (tb2) break;
			
			RTHOOK(15);
			F1147_10824(RTCW(loc2));
			RTHOOK(16);
			F1147_10824(RTCW(loc1));
		}
		RTHOOK(17);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_9_);
		F1140_10700(RTCW(tr1));
	}
	RTHOOK(18);
	RTLE;
	RTEE;
}

void EIF_Minit81 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
